@@ -28,10 +28,12 @@ from kubernetes.client.rest import ApiException
 from urllib3.exceptions import ReadTimeoutError
 
 from airflow.exceptions import AirflowException
+from airflow.providers.cncf.kubernetes.backcompat import get_logical_date_key
 from airflow.providers.cncf.kubernetes.executors.kubernetes_executor_types import (
     ADOPTED,
     ALL_NAMESPACES,
     POD_EXECUTOR_DONE_KEY,
+    POD_REVOKED_KEY,
 )
 from airflow.providers.cncf.kubernetes.kube_client import get_kube_client
 from airflow.providers.cncf.kubernetes.kubernetes_helper_functions import (
@@ -150,6 +152,7 @@ class KubernetesJobWatcher(multiprocessing.Process, LoggingMixin):
         kwargs["_request_timeout"] = client_timeout
         kwargs["timeout_seconds"] = server_conn_timeout
 
+        logical_date_key = get_logical_date_key()
         for event in self._pod_events(kube_client=kube_client, query_kwargs=kwargs):
             task = event["object"]
             self.log.debug("Event: %s had an event of type %s", task.metadata.name, event["type"])
@@ -159,7 +162,7 @@ class KubernetesJobWatcher(multiprocessing.Process, LoggingMixin):
             task_instance_related_annotations = {
                 "dag_id": annotations["dag_id"],
                 "task_id": annotations["task_id"],
-                "execution_date": annotations.get("execution_date"),
+                logical_date_key: annotations.get(logical_date_key),
                 "run_id": annotations.get("run_id"),
                 "try_number": annotations["try_number"],
             }
@@ -203,9 +206,13 @@ class KubernetesJobWatcher(multiprocessing.Process, LoggingMixin):
         resource_version: str,
         event: Any,
     ) -> None:
-        pod = event["object"]
-        annotations_string = annotations_for_logging_task_metadata(annotations)
         """Process status response."""
+        pod = event["object"]
+
+        if POD_REVOKED_KEY in pod.metadata.labels.keys():
+            return
+
+        annotations_string = annotations_for_logging_task_metadata(annotations)
         if event["type"] == "DELETED" and not pod.metadata.deletion_timestamp:
             # This will happen only when the task pods are adopted by another executor.
             # So, there is no change in the pod state.
@@ -431,7 +438,7 @@ class AirflowKubernetesScheduler(LoggingMixin):
     def delete_pod(self, pod_name: str, namespace: str) -> None:
         """Delete Pod from a namespace; does not raise if it does not exist."""
         try:
-            self.log.debug("Deleting pod %s in namespace %s", pod_name, namespace)
+            self.log.info("Deleting pod %s in namespace %s", pod_name, namespace)
             self.kube_client.delete_namespaced_pod(
                 pod_name,
                 namespace,
@@ -443,6 +450,26 @@ class AirflowKubernetesScheduler(LoggingMixin):
             if str(e.status) != "404":
                 raise
 
+    def patch_pod_revoked(self, *, pod_name: str, namespace: str):
+        """
+        Patch the pod with a label that ensures it's ignored by the kubernetes watcher.
+
+        :meta private:
+        """
+        self.log.info(
+            "Patching pod %s in namespace %s to note that we are revoking the task.",
+            pod_name,
+            namespace,
+        )
+        try:
+            self.kube_client.patch_namespaced_pod(
+                name=pod_name,
+                namespace=namespace,
+                body={"metadata": {"labels": {POD_REVOKED_KEY: "True"}}},
+            )
+        except ApiException:
+            self.log.warning("Failed to patch pod %s with pod revoked key.", pod_name, exc_info=True)
+
     def patch_pod_executor_done(self, *, pod_name: str, namespace: str):
         """Add a "done" annotation to ensure we don't continually adopt pods."""
         self.log.debug("Patching pod %s in namespace %s to mark it as done", pod_name, namespace)
